---
title: <span class="badge object-type-scalar"></span> WritesPerMinute
---
# <span class="badge object-type-scalar"></span> WritesPerMinute

Throughput: writes/min (wpm)

## Definition

```python
# Throughput: writes/min (wpm)
WritesPerMinute: typing.Literal["wpm"] = "wpm"
```
